@@ -2,7 +2,7 @@
 
 #
 # DaVinci Resolve 16.0 Debian package creator
-# Release 2019-08-09
+# Release 2019-09-10
 # By Daniel Tufvesson
 #
 
@@ -39,7 +39,7 @@ create_directory() {
 extract_tgz() {
     check_command tar
     if [ -f "$1" ] ; then
-	echo "[EXTRACT] $1 [TO] $2"
+	echo "[EXTRACT] $1 [TO] $2$3"
 	tar -zxf "$1" -C "$2" $3
     else
 	echo "[ERROR: MISSING] $1"
@@ -58,7 +58,7 @@ make_executable() {
 
 # Setup variables
 RESOLVE_VERSION=16.0
-DEB_STEPPING=1
+DEB_STEPPING=2
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -125,7 +125,6 @@ copy_object ${UNPACK_DIR}/scripts/script.start ${RESOLVE_BASE_DIR}/scripts/
 copy_object ${UNPACK_DIR}/share/default-config.dat ${RESOLVE_BASE_DIR}/share/
 copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/share/
 copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/share/
-copy_object ${UNPACK_DIR}/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/
 
 # Create udev rules
 create_directory ${DEB_DIR}/lib/udev/rules.d
@@ -140,6 +139,11 @@ EOF
 create_directory ${DEB_DIR}/usr/lib/
 extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/ libDaVinciPanelAPI.so
 
+# Create symlinks
+mkdir ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
+ln -s /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
+ln -s /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
+
 # Create common data dir
 create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
